@@ -37,14 +37,68 @@ import aiofiles
 
 import analytix
 from analytix import errors
-from analytix.abc import ReportType
+from analytix.abc import DynamicReportWriter, ReportType
 
-if analytix.can_use(all, "pandas"):
+if t.TYPE_CHECKING:
     import pandas as pd
 
 log = logging.getLogger(__name__)
 
 
+class JSONReportWriter(DynamicReportWriter):
+    __slots__ = ()
+
+    def _run_sync(self) -> None:
+        if not self._path.endswith(".json"):
+            self._path += ".json"
+
+        with open(self._path, "w") as f:
+            json.dump(self._data, f, indent=self._indent)
+
+        return log.info(f"Saved report as JSON to {Path(self._path).resolve()}")
+
+    async def _run_async(self) -> None:
+        if not self._path.endswith(".json"):
+            self._path += ".json"
+
+        async with aiofiles.open(self._path, "w") as f:
+            await f.write(json.dumps(self._data, indent=self._indent))
+
+        return log.info(f"Saved report as JSON to {Path(self._path).resolve()}")
+
+
+class CSVReportWriter(DynamicReportWriter):
+    __slots__ = ()
+
+    def _run_sync(self) -> None:
+        extension = ".tsv" if self._delimiter == "\t" else ".csv"
+
+        if not self._path.endswith(extension):
+            self._path += extension
+
+        with open(self._path, "w") as f:
+            f.write(f"{self._delimiter.join(self._columns)}\n")
+            for row in self._data["rows"]:
+                line = self._delimiter.join(f"{v}" for v in row)
+                f.write(f"{line}\n")
+
+        return log.info(f"Saved report as CSV to {Path(self._path).resolve()}")
+
+    async def _run_async(self) -> None:
+        extension = ".tsv" if self._delimiter == "\t" else ".csv"
+
+        if not self._path.endswith(extension):
+            self._path += extension
+
+        async with aiofiles.open(self._path, "w") as f:
+            await f.write(f"{self._delimiter.join(self._columns)}\n")
+            for row in self._data["rows"]:
+                line = self._delimiter.join(f"{v}" for v in row)
+                await f.write(f"{line}\n")
+
+        return log.info(f"Saved report as CSV to {Path(self._path).resolve()}")
+
+
 class Report:
     """A class representing a YouTube Analytics API report. You will
     never need to manually create an instance of this.
@@ -71,9 +125,12 @@ class Report:
 
         return (self._nrows, self._ncolumns)
 
-    def to_json(self, path: str, *, indent: int = 4) -> None:
+    def to_json(self, path: str, *, indent: int = 4) -> JSONReportWriter:
         """Write the report data to a JSON file.
 
+        .. note::
+            This method can also be run asynchronously by awaiting it.
+
         Args:
             path:
                 The path the file should be saved to.
@@ -82,40 +139,27 @@ class Report:
             indent:
                 The amount of indentation the data should be written
                 with. Defaults to ``4``.
+
+        Returns:
+            The report writer. This is done to allow this method to run
+            sync or async in a typed context.
         """
 
-        if not path.endswith(".json"):
-            path += ".json"
-
-        with open(path, "w") as f:
-            json.dump(self.data, f, indent=indent)
-
-        log.info(f"Saved report as JSON to {Path(path).resolve()}")
+        return JSONReportWriter(path, data=self.data, indent=indent)
 
     async def ato_json(self, path: str, *, indent: int = 4) -> None:
-        """Asynchronously write the report data to a JSON file.
+        log.warning(
+            "The `report.ato_json` method is deprecated -- "
+            "use `await report.to_json` instead"
+        )
+        await self.to_json(path, indent=indent)
 
-        Args:
-            path:
-                The path the file should be saved to.
-
-        Keyword Args:
-            indent:
-                The amount of indentation the data should be written
-                with. Defaults to ``4``.
-        """
-
-        if not path.endswith(".json"):
-            path += ".json"
-
-        async with aiofiles.open(path, "w") as f:
-            await f.write(json.dumps(self.data, indent=indent))
-
-        log.info(f"Saved report as JSON to {Path(path).resolve()}")
-
-    def to_csv(self, path: str, *, delimiter: str = ",") -> None:
+    def to_csv(self, path: str, *, delimiter: str = ",") -> CSVReportWriter:
         """Write the report data to a CSV file.
 
+        .. note::
+            This method can also be run asynchronously by awaiting it.
+
         Args:
             path:
                 The path the file should be saved to.
@@ -124,61 +168,78 @@ class Report:
             delimiter:
                 The delimiter to use. Defaults to a comma. Passing a tab
                 here will save the file as a TSV instead.
+
+        Returns:
+            The report writer. This is done to allow this method to run
+            sync or async in a typed context.
         """
 
-        extension = ".tsv" if delimiter == "\t" else ".csv"
-
-        if not path.endswith(extension):
-            path += extension
-
-        with open(path, "w") as f:
-            f.write(f"{delimiter.join(self.columns)}\n")
-            for row in self.data["rows"]:
-                line = delimiter.join(f"{v}" for v in row)
-                f.write(f"{line}\n")
-
-        log.info(f"Saved report as CSV to {Path(path).resolve()}")
+        return CSVReportWriter(
+            path,
+            data=self.data,
+            delimiter=delimiter,
+            columns=self.columns,
+        )
 
     async def ato_csv(self, path: str, *, delimiter: str = ",") -> None:
-        """Asynchronously write the report data to a CSV file.
+        log.warning(
+            "The `report.ato_csv` method is deprecated -- "
+            "use `await report.to_csv` instead"
+        )
+        await self.to_csv(path, delimiter=delimiter)
+
+    def to_excel(self, path: str, *, sheet_name: str = "Analytics") -> None:
+        """Write the report data to an Excel spreadsheet.
 
         Args:
             path:
                 The path the file should be saved to.
 
         Keyword Args:
-            delimiter:
-                The delimiter to use. Defaults to a comma. Passing a tab
-                here will save the file as a TSV instead.
+            sheet_name:
+                The name for the worksheet.
+
+        .. versionadded:: 3.1.0
         """
 
-        extension = ".tsv" if delimiter == "\t" else ".csv"
+        if analytix.can_use("openpyxl"):
+            from openpyxl import Workbook
+        else:
+            raise errors.MissingOptionalComponents("openpyxl")
 
-        if not path.endswith(extension):
-            path += extension
+        if not path.endswith(".xlsx"):
+            path += ".xlsx"
 
-        async with aiofiles.open(path, "w") as f:
-            await f.write(f"{delimiter.join(self.columns)}\n")
-            for row in self.data["rows"]:
-                line = delimiter.join(f"{v}" for v in row)
-                await f.write(f"{line}\n")
+        wb = Workbook()
+        ws = wb.active
+        ws.title = sheet_name
 
-        log.info(f"Saved report as CSV to {Path(path).resolve()}")
+        ws.append(self.columns)
+        for row in self.data["rows"]:
+            ws.append(row)
+
+        wb.save(path)
+        log.info(f"Saved report as spreadsheet to {Path(path).resolve()}")
 
     def to_dataframe(self, *, skip_date_conversion: bool = False) -> pd.DataFrame:
-        """Export the report data to a pandas DataFrame.
-
-        .. note::
-            The pandas library is required to do this, but is not
-            automatically installed by analytix.
+        """Export the report data to a DataFrame. If you wish to use
+        Modin, you are responsible for selecting and initialising your
+        desired engine.
 
         Keyword Args:
             skip_date_conversion:
                 Whether to skip automatically converting date columns to
                 the ``datetime64[ns]`` format. Defaults to ``False``.
+
+        Returns:
+            The newly created pandas DataFrame.
         """
 
-        if not analytix.can_use(all, "pandas"):
+        if analytix.can_use("modin"):
+            import modin.pandas as pd
+        elif analytix.can_use("pandas"):
+            import pandas as pd
+        else:
             raise errors.MissingOptionalComponents("pandas")
 
         if not self._nrows:
